/**
 * Copyright (C) 2003-2005 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
 */
package sync4j.syncclient.common;

/**
 * Utility class that groups string manipulation functions.
 *
 * @author  Stefano Fornari
 * @version $Id: StringTools.java,v 1.4 2005/01/19 11:17:41 fabius Exp $
 */
public class StringTools {

    /**
     * <p>Escapes the characters in a <code>String</code> using XML entities.</p>
     *
     *
     * <p>Supports only the four basic XML entities (gt, lt, quot, amp).
     * Does not support DTDs or external entities.</p>
     *
     * @param str  the <code>String</code> to escape, may be null
     * @return a new escaped <code>String</code>, <code>null</code> if null string input
     * @see #unescapeXml(java.lang.String)
     **/
    public static String escapeXml(String str) {
        if (str == null) {
            return null;
        }
        return Entities.XML.escape(str);
    }

    /**
     * <p>Unescapes a string containing XML entity escapes to a string
     * containing the actual Unicode characters corresponding to the
     * escapes.</p>
     *
     * <p>Supports only the four basic XML entities (gt, lt, quot, amp).
     * Does not support DTDs or external entities.</p>
     *
     * @param str  the <code>String</code> to unescape, may be null
     * @return a new unescaped <code>String</code>, <code>null</code> if null string input
     * @see #escapeXml(String)
     **/
    public static String unescapeXml(String str) {
        if (str == null) {
            return null;
        }
        return Entities.XML.unescape(str);
    }

    /**
     * drop '\n'
     * @param content
     * @return replaced content
     */
    public static String changeNewLine(String content) {

        StringBuffer b = null;

        b = new StringBuffer();

        char c = ' ';

        for (int i = 0, l = content.length(); i < l; i++) {

            c = content.charAt(i);

            if  (c != '\n') {
                b.append(c);
            }

        }

        return b.toString();

    }

    /**
     * Replace '\r' by '\r\n'
     * @param content
     * @return replaced content
     */
    public static String restoreNewLine(String content) {

        StringBuffer b = null;

        int          i = 0   ;
        int          l = 0   ;

        b = new StringBuffer();

        for (i= 0, l = content.length(); i < l - 1; i ++) {
            b.append(content.charAt(i));

            if ((content.charAt(i) == '\r') && (content.charAt(i+1) != '\n')) {
              b.append('\n');
            }

        }

        b.append(content.charAt(i));

        if (content.charAt(i) == '\r') {
          b.append('\n');
        }

        return b.toString();
    }


}